// java wrapper for vtkGlyph3DMapper object
//

package vtk;
import vtk.*;

public class vtkGlyph3DMapper extends vtkMapper
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSourceConnection_2(int id0,vtkAlgorithmOutput id1);
  public void SetSourceConnection(int id0,vtkAlgorithmOutput id1)
    { SetSourceConnection_2(id0,id1); }

  private native void SetSourceConnection_3(vtkAlgorithmOutput id0);
  public void SetSourceConnection(vtkAlgorithmOutput id0)
    { SetSourceConnection_3(id0); }

  private native void SetInputData_4(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_4(id0); }

  private native void SetSourceData_5(int id0,vtkPolyData id1);
  public void SetSourceData(int id0,vtkPolyData id1)
    { SetSourceData_5(id0,id1); }

  private native void SetSourceTableTree_6(vtkDataObjectTree id0);
  public void SetSourceTableTree(vtkDataObjectTree id0)
    { SetSourceTableTree_6(id0); }

  private native void SetSourceData_7(vtkPolyData id0);
  public void SetSourceData(vtkPolyData id0)
    { SetSourceData_7(id0); }

  private native long GetSource_8(int id0);
  public vtkPolyData GetSource(int id0) {
    long temp = GetSource_8(id0);

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSourceTableTree_9();
  public vtkDataObjectTree GetSourceTableTree() {
    long temp = GetSourceTableTree_9();

    if (temp == 0) return null;
    return (vtkDataObjectTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScaling_10(boolean id0);
  public void SetScaling(boolean id0)
    { SetScaling_10(id0); }

  private native void ScalingOn_11();
  public void ScalingOn()
    { ScalingOn_11(); }

  private native void ScalingOff_12();
  public void ScalingOff()
    { ScalingOff_12(); }

  private native boolean GetScaling_13();
  public boolean GetScaling()
    { return GetScaling_13(); }

  private native void SetScaleMode_14(int id0);
  public void SetScaleMode(int id0)
    { SetScaleMode_14(id0); }

  private native int GetScaleMode_15();
  public int GetScaleMode()
    { return GetScaleMode_15(); }

  private native void SetScaleFactor_16(double id0);
  public void SetScaleFactor(double id0)
    { SetScaleFactor_16(id0); }

  private native double GetScaleFactor_17();
  public double GetScaleFactor()
    { return GetScaleFactor_17(); }

  private native void SetScaleModeToScaleByMagnitude_18();
  public void SetScaleModeToScaleByMagnitude()
    { SetScaleModeToScaleByMagnitude_18(); }

  private native void SetScaleModeToScaleByVectorComponents_19();
  public void SetScaleModeToScaleByVectorComponents()
    { SetScaleModeToScaleByVectorComponents_19(); }

  private native void SetScaleModeToNoDataScaling_20();
  public void SetScaleModeToNoDataScaling()
    { SetScaleModeToNoDataScaling_20(); }

  private native String GetScaleModeAsString_21();
  public String GetScaleModeAsString()
    { return GetScaleModeAsString_21(); }

  private native void SetRange_22(double id0,double id1);
  public void SetRange(double id0,double id1)
    { SetRange_22(id0,id1); }

  private native void SetRange_23(double id0[]);
  public void SetRange(double id0[])
    { SetRange_23(id0); }

  private native double[] GetRange_24();
  public double[] GetRange()
    { return GetRange_24(); }

  private native void SetOrient_25(boolean id0);
  public void SetOrient(boolean id0)
    { SetOrient_25(id0); }

  private native boolean GetOrient_26();
  public boolean GetOrient()
    { return GetOrient_26(); }

  private native void OrientOn_27();
  public void OrientOn()
    { OrientOn_27(); }

  private native void OrientOff_28();
  public void OrientOff()
    { OrientOff_28(); }

  private native void SetOrientationMode_29(int id0);
  public void SetOrientationMode(int id0)
    { SetOrientationMode_29(id0); }

  private native int GetOrientationModeMinValue_30();
  public int GetOrientationModeMinValue()
    { return GetOrientationModeMinValue_30(); }

  private native int GetOrientationModeMaxValue_31();
  public int GetOrientationModeMaxValue()
    { return GetOrientationModeMaxValue_31(); }

  private native int GetOrientationMode_32();
  public int GetOrientationMode()
    { return GetOrientationMode_32(); }

  private native void SetOrientationModeToDirection_33();
  public void SetOrientationModeToDirection()
    { SetOrientationModeToDirection_33(); }

  private native void SetOrientationModeToRotation_34();
  public void SetOrientationModeToRotation()
    { SetOrientationModeToRotation_34(); }

  private native void SetOrientationModeToQuaternion_35();
  public void SetOrientationModeToQuaternion()
    { SetOrientationModeToQuaternion_35(); }

  private native String GetOrientationModeAsString_36();
  public String GetOrientationModeAsString()
    { return GetOrientationModeAsString_36(); }

  private native void SetClamping_37(boolean id0);
  public void SetClamping(boolean id0)
    { SetClamping_37(id0); }

  private native boolean GetClamping_38();
  public boolean GetClamping()
    { return GetClamping_38(); }

  private native void ClampingOn_39();
  public void ClampingOn()
    { ClampingOn_39(); }

  private native void ClampingOff_40();
  public void ClampingOff()
    { ClampingOff_40(); }

  private native void SetSourceIndexing_41(boolean id0);
  public void SetSourceIndexing(boolean id0)
    { SetSourceIndexing_41(id0); }

  private native boolean GetSourceIndexing_42();
  public boolean GetSourceIndexing()
    { return GetSourceIndexing_42(); }

  private native void SourceIndexingOn_43();
  public void SourceIndexingOn()
    { SourceIndexingOn_43(); }

  private native void SourceIndexingOff_44();
  public void SourceIndexingOff()
    { SourceIndexingOff_44(); }

  private native void SetUseSourceTableTree_45(boolean id0);
  public void SetUseSourceTableTree(boolean id0)
    { SetUseSourceTableTree_45(id0); }

  private native boolean GetUseSourceTableTree_46();
  public boolean GetUseSourceTableTree()
    { return GetUseSourceTableTree_46(); }

  private native void UseSourceTableTreeOn_47();
  public void UseSourceTableTreeOn()
    { UseSourceTableTreeOn_47(); }

  private native void UseSourceTableTreeOff_48();
  public void UseSourceTableTreeOff()
    { UseSourceTableTreeOff_48(); }

  private native void SetUseSelectionIds_49(boolean id0);
  public void SetUseSelectionIds(boolean id0)
    { SetUseSelectionIds_49(id0); }

  private native void UseSelectionIdsOn_50();
  public void UseSelectionIdsOn()
    { UseSelectionIdsOn_50(); }

  private native void UseSelectionIdsOff_51();
  public void UseSelectionIdsOff()
    { UseSelectionIdsOff_51(); }

  private native boolean GetUseSelectionIds_52();
  public boolean GetUseSelectionIds()
    { return GetUseSelectionIds_52(); }

  private native void GetBounds_53(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_53(id0); }

  private native void Render_54(vtkRenderer id0,vtkActor id1);
  public void Render(vtkRenderer id0,vtkActor id1)
    { Render_54(id0,id1); }

  private native void SetMasking_55(boolean id0);
  public void SetMasking(boolean id0)
    { SetMasking_55(id0); }

  private native boolean GetMasking_56();
  public boolean GetMasking()
    { return GetMasking_56(); }

  private native void MaskingOn_57();
  public void MaskingOn()
    { MaskingOn_57(); }

  private native void MaskingOff_58();
  public void MaskingOff()
    { MaskingOff_58(); }

  private native void SetMaskArray_59(String id0);
  public void SetMaskArray(String id0)
    { SetMaskArray_59(id0); }

  private native void SetMaskArray_60(int id0);
  public void SetMaskArray(int id0)
    { SetMaskArray_60(id0); }

  private native void SetOrientationArray_61(String id0);
  public void SetOrientationArray(String id0)
    { SetOrientationArray_61(id0); }

  private native void SetOrientationArray_62(int id0);
  public void SetOrientationArray(int id0)
    { SetOrientationArray_62(id0); }

  private native void SetScaleArray_63(String id0);
  public void SetScaleArray(String id0)
    { SetScaleArray_63(id0); }

  private native void SetScaleArray_64(int id0);
  public void SetScaleArray(int id0)
    { SetScaleArray_64(id0); }

  private native void SetSourceIndexArray_65(String id0);
  public void SetSourceIndexArray(String id0)
    { SetSourceIndexArray_65(id0); }

  private native void SetSourceIndexArray_66(int id0);
  public void SetSourceIndexArray(int id0)
    { SetSourceIndexArray_66(id0); }

  private native void SetSelectionIdArray_67(String id0);
  public void SetSelectionIdArray(String id0)
    { SetSelectionIdArray_67(id0); }

  private native void SetSelectionIdArray_68(int id0);
  public void SetSelectionIdArray(int id0)
    { SetSelectionIdArray_68(id0); }

  private native void SetSelectionColorId_69(int id0);
  public void SetSelectionColorId(int id0)
    { SetSelectionColorId_69(id0); }

  private native int GetSelectionColorId_70();
  public int GetSelectionColorId()
    { return GetSelectionColorId_70(); }

  private native void SetBlockAttributes_71(vtkCompositeDataDisplayAttributes id0);
  public void SetBlockAttributes(vtkCompositeDataDisplayAttributes id0)
    { SetBlockAttributes_71(id0); }

  private native long GetBlockAttributes_72();
  public vtkCompositeDataDisplayAttributes GetBlockAttributes() {
    long temp = GetBlockAttributes_72();

    if (temp == 0) return null;
    return (vtkCompositeDataDisplayAttributes)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCullingAndLOD_73(boolean id0);
  public void SetCullingAndLOD(boolean id0)
    { SetCullingAndLOD_73(id0); }

  private native boolean GetCullingAndLOD_74();
  public boolean GetCullingAndLOD()
    { return GetCullingAndLOD_74(); }

  private native int GetMaxNumberOfLOD_75();
  public int GetMaxNumberOfLOD()
    { return GetMaxNumberOfLOD_75(); }

  private native void SetNumberOfLOD_76(int id0);
  public void SetNumberOfLOD(int id0)
    { SetNumberOfLOD_76(id0); }

  private native void SetLODDistanceAndTargetReduction_77(int id0,double id1,double id2);
  public void SetLODDistanceAndTargetReduction(int id0,double id1,double id2)
    { SetLODDistanceAndTargetReduction_77(id0,id1,id2); }

  private native void SetLODColoring_78(boolean id0);
  public void SetLODColoring(boolean id0)
    { SetLODColoring_78(id0); }

  private native boolean GetLODColoring_79();
  public boolean GetLODColoring()
    { return GetLODColoring_79(); }

  private native boolean GetSupportsSelection_80();
  public boolean GetSupportsSelection()
    { return GetSupportsSelection_80(); }

  public vtkGlyph3DMapper() { super(); }

  public vtkGlyph3DMapper(long id) { super(id); }
  public native long   VTKInit();

}
